window.Gleam.initSearch([{"doc":"dig","title":"dig","content":"# dig\n\n[![Package Version](https://img.shields.io/hexpm/v/dig?color=92DCE5)](https://hex.pm/packages/dig)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3?color=FCC0D2)](https://hexdocs.pm/dig/)\n\n✨ Parse path expression as [dynamic.Decoder](https://hexdocs.pm/gleam_stdlib/gleam/dynamic.html#Decoder)\n\n## Installation\n\nTo add this package to your Gleam project:\n\n```sh\ngleam add dig\n```\n\n## Usage\n\n```gleam\nimport gleeunit\nimport gleeunit/should\nimport dig\nimport gleam/option.{None, Some}\nimport gleam/json\nimport gleam/dynamic\nimport gleam/string\nimport gleam/list\nimport gleam/io\n\npub fn dig_test() {\n  let json_str =\n    &quot;\n  {\n    \\&quot;foo\\&quot;: [\n      {\n        \\&quot;bar\\&quot;: [\n          {\n            \\&quot;baz\\&quot;: \\&quot;a\\&quot;\n          },\n          {\n            \\&quot;baz\\&quot;: \\&quot;b\\&quot;\n          }\n        ]\n      },\n      {\n        \\&quot;bar\\&quot;: [\n           {\n            \\&quot;baz\\&quot;: \\&quot;c\\&quot;\n          },\n          {\n            \\&quot;baz\\&quot;: \\&quot;d\\&quot;\n          }\n        ]\n      }\n    ],\n    \\&quot;haha\\&quot;: {\n      \\&quot;meme\\&quot;: 1\n    }\n  }\n  &quot;\n\n  {\n    let assert Ok(dig.DigObject(path, decoder)) =\n      dig.dig(\n        &quot;foo[1].bar[1].baz&quot;\n        |&gt; string.split(&quot;.&quot;),\n      )\n\n    should.equal(path, [&quot;foo[1]&quot;, &quot;bar[1]&quot;, &quot;baz&quot;])\n\n    let assert Ok(d) =\n      json_str\n      |&gt; json.decode(decoder)\n\n    d\n    |&gt; dynamic.string()\n    |&gt; should.equal(Ok(&quot;d&quot;))\n  }\n\n  {\n    let assert Ok(dig.DigList(path, decoder)) =\n      dig.dig(\n        &quot;foo[].bar[].baz&quot;\n        |&gt; string.split(&quot;.&quot;),\n      )\n\n    should.equal(path, [&quot;foo[]&quot;, &quot;bar[]&quot;, &quot;baz&quot;])\n\n    let assert Ok(d) =\n      json_str\n      |&gt; json.decode(decoder)\n\n    d\n    |&gt; list.map(dynamic.string)\n    |&gt; should.equal([Ok(&quot;a&quot;), Ok(&quot;b&quot;), Ok(&quot;c&quot;), Ok(&quot;d&quot;)])\n  }\n\n  {\n    let assert Ok(dig.DigList(path, decoder)) =\n      dig.dig(\n        &quot;foo[].miss_me[1].baz&quot;\n        |&gt; string.split(&quot;.&quot;),\n      )\n\n    should.equal(path, [&quot;foo[]&quot;, &quot;miss_me[1]&quot;, &quot;baz&quot;])\n\n    let r =\n      json_str\n      |&gt; json.decode(decoder)\n\n    case r {\n      Ok(_) -&gt; should.fail()\n      Error(errors) -&gt; {\n        io.debug(errors)\n        Nil\n      }\n    }\n  }\n}\n```\n\n","url":"index.html"},{"doc":"dig","title":"DigDecoder","content":"pub type DigDecoder {\n  DigObject(path: List(String), inner: Decoder(Dynamic))\n  DigList(path: List(String), inner: Decoder(List(Dynamic)))\n}\n wrap `dynamic.Decoder` with a path\n\nDigObject(path: List(String), inner: Decoder(Dynamic))\n\n\nDigList(path: List(String), inner: Decoder(List(Dynamic)))\n\n\nSynonyms:\ndig.DigDecoder\ndig DigDecoder","url":"dig.html#DigDecoder"},{"doc":"dig","title":"DigError","content":"pub type DigError {\n  EmptyPath\n  ParsePath(inner: PathSegParseError)\n}\n\nEmptyPath\n\n\nParsePath(inner: PathSegParseError)\n\n\nSynonyms:\ndig.DigError\ndig DigError","url":"dig.html#DigError"},{"doc":"dig","title":"DigResult","content":"pub type DigResult =\n  Result(DigDecoder, DigError)\n `Ok(DigDecoder)` or `Error(DigError)`\n\n\nSynonyms:\ndig.DigResult\ndig DigResult","url":"dig.html#DigResult"},{"doc":"dig","title":"PathSeg","content":"pub type PathSeg {\n  Object(key: String)\n  List(key: Option(String), index: Option(Int))\n}\n\nObject(key: String)\n\n\nList(key: Option(String), index: Option(Int))\n\n\nSynonyms:\ndig.PathSeg\ndig PathSeg","url":"dig.html#PathSeg"},{"doc":"dig","title":"PathSegParseError","content":"pub type PathSegParseError {\n  InvalidPathSeg(path_seg: String)\n}\n\nInvalidPathSeg(path_seg: String)\n\n\nSynonyms:\ndig.PathSegParseError\ndig PathSegParseError","url":"dig.html#PathSegParseError"},{"doc":"dig","title":"PathSegParseResult","content":"pub type PathSegParseResult =\n  Result(PathSeg, PathSegParseError)\n\n\nSynonyms:\ndig.PathSegParseResult\ndig PathSegParseResult","url":"dig.html#PathSegParseResult"},{"doc":"dig","title":"compose","content":"pub fn compose(a: DigDecoder, b: DigDecoder) -&gt; DigDecoder\n compose two `DigDecoder`s\n\nSynonyms:\ndig.compose\ndig compose","url":"dig.html#compose"},{"doc":"dig","title":"dig","content":"pub fn dig(path: List(String)) -&gt; Result(DigDecoder, DigError)\n dig `dynamic.Encoder` in path\n\nSynonyms:\ndig.dig\ndig dig","url":"dig.html#dig"},{"doc":"dig","title":"dig_path_seg","content":"pub fn dig_path_seg(\n  path_seg: String,\n) -&gt; Result(DigDecoder, DigError)\n dig `dynamic.Decoder` in single path segment\n\nSynonyms:\ndig.dig_path_seg\ndig dig_path_seg","url":"dig.html#dig_path_seg"},{"doc":"dig","title":"parse_path_seg","content":"pub fn parse_path_seg(\n  path_seg: String,\n) -&gt; Result(PathSeg, PathSegParseError)\n parse single path segment\n\nSynonyms:\ndig.parse_path_seg\ndig parse_path_seg","url":"dig.html#parse_path_seg"},{"doc":"dig","title":"dig","content":"","url":"dig.html"}]);